.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

xreducer
========

Defined in ``xtensor/xreducer.hpp``

.. doxygenclass:: xt::xreducer
   :project: xtensor
   :members:

.. doxygenfunction:: xt::reduce(F&&, E&&, X&&, EVS&&)
   :project: xtensor
